## CyberSIEM Community Kit

* An open-source "Swiss Army Knife" for anything SIEM related!

* While this project is gaining rapid progress, it is far from ready..

    - **WARNING!** _This toolkit is still experimental and we do not recommended it for use in production. Do note that 
    at this stage we are not yet releasing stable versions as the API changes on daily basis!_

## Installation

```bash
pip install siemkit
```

## Updating

```bash
pip install --upgrade siemkit
```

Package:
   - https://pypi.org/project/siemkit/  

GitHub: 
   - https://github.com/cybersiem/community

## Libraries

- `siemkit.csv`
- `siemkit.event`
- `siemkit.file`
- `siemkit.flag`
- `siemkit.ldap`
- `siemkit.parse`
- `siemkit.time`
- `siemkit.data`
- `siemkit.logging`
- `siemkit.receive`
- `siemkit.send`

_Work in progress . . ._